@@ -177,7 +177,7 @@ dtilin.smooth <- function(object,hmax=5,hinit=NULL,lambda=52,
      z <- .Fortran(C_awssidti,
                 as.double(s0),
                 as.double(si),
-                as.logical(mask),
+                as.integer(mask),
                 as.double(z$D),
                 bi=as.double(z$bi),
                 anindex=as.double(z$anindex),
