@@ -411,8 +411,8 @@ readDWIdata <- function(gradient, dirlist,
 setMethod("print", "dtiData",
           function(x){
             cat("  Object of class", class(x),"\n")
-            cat("  Generated by calls   :\n")
-            print(x@call)
+#            cat("  Generated by calls   :\n")
+#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -425,8 +425,8 @@ setMethod("print", "dtiData",
 setMethod("print", "dtiTensor",
           function(x){
             cat("  Object of class", class(x),"\n")
-            cat("  Generated by calls   :\n")
-            print(x@call)
+#            cat("  Generated by calls   :\n")
+#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -440,8 +440,8 @@ setMethod("print", "dtiTensor",
 setMethod( "print", "dkiTensor",
            function( x) {
              cat( "  Object of class", class(x), "\n")
-             cat( "  Generated by calls   :\n")
-             print( x@call)
+#             cat( "  Generated by calls   :\n")
+#             print( x@call)
              cat( "  Dimension            :", paste( x@ddim, collapse = "x"), "\n")
              ns0 <- length( x@s0ind)
              cat( "  Number of S0 images  :", paste( ns0, collapse = "x"), "\n")
@@ -455,8 +455,8 @@ setMethod( "print", "dkiTensor",
 setMethod("print", "dwiMixtensor",
           function(x){
             cat("  Object of class", class(x),"\n")
-            cat("  Generated by calls   :\n")
-            print(x@call)
+#            cat("  Generated by calls   :\n")
+#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -470,8 +470,8 @@ setMethod("print", "dwiMixtensor",
 setMethod("print", "dwiQball",
           function(x){
             cat("  Object of class", class(x),"\n")
-            cat("  Generated by calls   :\n")
-            print(x@call)
+#            cat("  Generated by calls   :\n")
+#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -486,8 +486,8 @@ setMethod("print", "dwiQball",
 setMethod("print","dtiIndices",
           function(x){
             cat("  Object of class", class(x),"\n")
-            cat("  Generated by calls   :\n")
-            print(x@call)
+#            cat("  Generated by calls   :\n")
+#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -501,8 +501,8 @@ setMethod("print","dtiIndices",
 setMethod("print","dkiIndices",
           function(x){
             cat("  Object of class", class(x),"\n")
-            cat("  Generated by calls   :\n")
-            print(x@call)
+#            cat("  Generated by calls   :\n")
+#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -516,8 +516,8 @@ setMethod("print","dkiIndices",
 setMethod("print","dwiFiber",
           function(x){
             cat("  Object of class", class(x),"\n")
-            cat("  Generated by calls   :\n")
-            print(x@call)
+#            cat("  Generated by calls   :\n")
+#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -533,8 +533,8 @@ setMethod("print","dwiFiber",
 setMethod("show", "dtiData",
           function(object){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls   :\n")
-            print(object@call)
+#            cat("  Generated by calls   :\n")
+#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -547,8 +547,8 @@ setMethod("show", "dtiData",
 setMethod("show", "dtiTensor",
           function(object){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls   :\n")
-            print(object@call)
+#            cat("  Generated by calls   :\n")
+#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -562,8 +562,8 @@ setMethod("show", "dtiTensor",
 setMethod( "show", "dkiTensor",
            function( object) {
              cat( "  Object of class", class( object), "\n")
-             cat( "  Generated by calls   :\n")
-             print( object@call)
+#             cat( "  Generated by calls   :\n")
+#             print( object@call)
              cat( "  Dimension            :", paste( object@ddim, collapse = "x"), "\n")
              ns0 <- length( object@s0ind)
              cat( "  Number of S0 images  :", paste( ns0, collapse = "x"), "\n")
@@ -577,8 +577,8 @@ setMethod( "show", "dkiTensor",
 setMethod("show", "dwiMixtensor",
           function(object){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls   :\n")
-            print(object@call)
+#            cat("  Generated by calls   :\n")
+#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -592,8 +592,8 @@ setMethod("show", "dwiMixtensor",
 setMethod("show", "dtiIndices",
           function(object){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls   :\n")
-            print(object@call)
+#            cat("  Generated by calls   :\n")
+#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -607,8 +607,8 @@ setMethod("show", "dtiIndices",
 setMethod("show", "dkiIndices",
           function(object){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls   :\n")
-            print(object@call)
+#            cat("  Generated by calls   :\n")
+#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -622,8 +622,8 @@ setMethod("show", "dkiIndices",
 setMethod("show","dwiFiber",
           function(object){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls   :\n")
-            print(object@call)
+#            cat("  Generated by calls   :\n")
+#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -639,20 +639,15 @@ setMethod("show","dwiFiber",
 setMethod("summary", "dtiData",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls    :\n")
-            print(object@call)
-            cat("  Source-Filename       :", object@source, "\n")
+#            cat("  Generated by calls    :\n")
+#            print(object@call)
+#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
             cat("  Number of Gradients   :", paste(object@ngrad-ns0, collapse="x"), "\n")
             cat("  Voxel extensions      :", paste(signif(object@voxelext,3), collapse="x"), "\n")
-            if(ns0>14){
-              cat("  Index of S0-Images    :", paste(object@s0ind[1:14], collapse=" "), "\n", fill=TRUE)
-              cat(paste(object@s0ind[15:ns0], collapse=" "), "\n")
-            } else {
-              cat("  Index of S0-Images    :", paste(object@s0ind, collapse=" "), "\n", fill=TRUE)
-            }
+            cat("  Index of S0-Images    :", object@s0ind, "\n", fill=TRUE)
             cat("  Quantiles of S0-values:","\n")
             print(signif(quantile(object@si[,,,object@s0ind],...),3))
             cat("  Mean S0-value         :", signif(mean(object@si[,,,object@s0ind]),3), "\n")
@@ -663,9 +658,9 @@ setMethod("summary", "dtiData",
 setMethod("summary", "dtiTensor",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls    :\n")
-            print(object@call)
-            cat("  Source-Filename       :", object@source, "\n")
+#            cat("  Generated by calls    :\n")
+#            print(object@call)
+#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ngrad <- object@ngrad
             ns0 <- length(object@s0ind)
@@ -689,9 +684,9 @@ setMethod("summary", "dtiTensor",
 setMethod( "summary", "dkiTensor",
            function( object, ...) {
              cat( "  Object of class", class( object), "\n")
-             cat( "  Generated by calls    :\n")
-             print( object@call)
-             cat( "  Source-Filename       :", object@source, "\n")
+#             cat( "  Generated by calls    :\n")
+#             print( object@call)
+#             cat( "  Source-Filename       :", object@source, "\n")
              cat( "  Dimension             :", paste( object@ddim, collapse = "x"), "\n")
              ngrad <- object@ngrad
              ns0 <- length( object@s0ind)
@@ -715,9 +710,9 @@ setMethod( "summary", "dkiTensor",
 setMethod("summary", "dwiMixtensor",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls    :\n")
-            print(object@call)
-            cat("  Source-Filename       :", object@source, "\n")
+#            cat("  Generated by calls    :\n")
+#            print(object@call)
+#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ngrad <- object@ngrad
             ns0 <- length(object@s0ind)
@@ -743,9 +738,9 @@ setMethod("summary", "dwiMixtensor",
 setMethod("summary", "dwiQball",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls    :\n")
-            print(object@call)
-            cat("  Source-Filename       :", object@source, "\n")
+#            cat("  Generated by calls    :\n")
+#            print(object@call)
+#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
@@ -770,9 +765,9 @@ setMethod("summary", "dwiQball",
 setMethod("summary", "dtiIndices",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls    :\n")
-            print(object@call)
-            cat("  Source-Filename       :", object@source, "\n")
+#            cat("  Generated by calls    :\n")
+#            print(object@call)
+#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
@@ -792,9 +787,9 @@ setMethod("summary", "dtiIndices",
 setMethod("summary", "dkiIndices",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls    :\n")
-            print(object@call)
-            cat("  Source-Filename       :", object@source, "\n")
+#            cat("  Generated by calls    :\n")
+#            print(object@call)
+#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
@@ -814,9 +809,9 @@ setMethod("summary", "dkiIndices",
 setMethod("summary","dwiFiber",
           function(object){
             cat("  Object of class", class(object),"\n")
-            cat("  Generated by calls    :\n")
-            print(object@call)
-            cat("  Source-Filename       :", object@source, "\n")
+#            cat("  Generated by calls    :\n")
+#            print(object@call)
+#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
